@@ -147,12 +147,12 @@ JSON_DATA = '''
 
 '''
 DOT_DATA = '''\
-strict digraph  {
-0 [id=nova, vitrage_sample_timestamp="2018-12-31T13:44:03Z", vitrage_datasource_name="nova.zone", vitrage_operational_state=OK, state=available, update_timestamp="2018-12-31T13:44:03Z", is_real_vitrage_id=True, vitrage_id="05a19de3-e929-4730-ad81-10fa57dcfa0a", vitrage_aggregated_state=AVAILABLE, vitrage_type="nova.zone", vitrage_is_deleted=False, vitrage_category=RESOURCE, vitrage_cached_id=125f1d8c4451a6385cc2cfa2b0ba45be, vitrage_is_placeholder=False, label="nova\\nnova.zone"];
-1 [id="OpenStack Cluster", vitrage_sample_timestamp="2018-12-31T13:44:03Z", vitrage_operational_state=OK, state=available, vitrage_id="070c413e-5a8c-4823-ae20-af44936de2a0", vitrage_aggregated_state=AVAILABLE, vitrage_type="openstack.cluster", is_real_vitrage_id=True, vitrage_category=RESOURCE, vitrage_cached_id=3c7f9d22d9dd1615a00404f86cb3e289, vitrage_is_deleted=False, vitrage_is_placeholder=False, label="openstack.cluster"];
-2 [id="ebarilan-devstack", vitrage_sample_timestamp="2018-12-31T13:44:03Z", vitrage_datasource_name="nova.host", vitrage_operational_state=OK, state=available, update_timestamp="2018-12-31T13:44:03Z", is_real_vitrage_id=True, vitrage_id="10da4fa2-397f-4b2e-a43b-937e11ab7daf", vitrage_aggregated_state=AVAILABLE, vitrage_type="nova.host", vitrage_is_deleted=False, vitrage_category=RESOURCE, vitrage_cached_id=9ae4db6fb920e19cb5c57a428b29eb59, vitrage_is_placeholder=False, label="ebarilan-devstack\\nnova.host"];
-3 [id="b36b4d7a-b309-4b02-9662-5abd79741750", vitrage_sample_timestamp="2018-12-31T13:44:04Z", vitrage_datasource_name="cinder.volume", project_id=210140f1f5a94af99e0adf79a883b75a, vitrage_operational_state=OK, vitrage_aggregated_state=AVAILABLE, vitrage_is_placeholder=False, state=available, attachments="[]", vitrage_id="f0ca9fac-3ebd-4748-97ba-e93a7e7108aa", size=1, vitrage_type="cinder.volume", vitrage_is_deleted=False, vitrage_category=RESOURCE, vitrage_cached_id=f998c5f7bf1851e17e3eea902800a7df, update_timestamp="2018-12-31T08:43:32Z", is_real_vitrage_id=True, volume_type="lvmdriver-1", label="cinder.volume"];
-4 [id="cebf5d5b-d7b1-4cfb-86fa-f660306b4c1a", vitrage_sample_timestamp="2018-12-31T13:44:04Z", vitrage_datasource_name="neutron.network", project_id=210140f1f5a94af99e0adf79a883b75a, vitrage_operational_state=OK, vitrage_category=RESOURCE, vitrage_is_placeholder=False, state=ACTIVE, update_timestamp="2018-12-30T08:30:33Z", is_real_vitrage_id=True, vitrage_id="eea46e33-81dc-4430-a771-852bac37b43d", vitrage_aggregated_state=ACTIVE, vitrage_type="neutron.network", vitrage_is_deleted=False, vitrage_cached_id=a0eeca0ab2c865915e23319a2e6d0fd7, label="public\\nneutron.network"];
+strict digraph {
+0 [id=nova, vitrage_sample_timestamp="2018-12-31T13:44:03Z", vitrage_datasource_name="nova.zone", vitrage_operational_state=OK, state=available, update_timestamp="2018-12-31T13:44:03Z", is_real_vitrage_id=True, vitrage_id="05a19de3-e929-4730-ad81-10fa57dcfa0a", vitrage_aggregated_state=AVAILABLE, vitrage_type="nova.zone", vitrage_is_deleted=False, vitrage_category=RESOURCE, vitrage_cached_id="125f1d8c4451a6385cc2cfa2b0ba45be", vitrage_is_placeholder=False, label="nova\\nnova.zone"];
+1 [id="OpenStack Cluster", vitrage_sample_timestamp="2018-12-31T13:44:03Z", vitrage_operational_state=OK, state=available, vitrage_id="070c413e-5a8c-4823-ae20-af44936de2a0", vitrage_aggregated_state=AVAILABLE, vitrage_type="openstack.cluster", is_real_vitrage_id=True, vitrage_category=RESOURCE, vitrage_cached_id="3c7f9d22d9dd1615a00404f86cb3e289", vitrage_is_deleted=False, vitrage_is_placeholder=False, label="openstack.cluster"];
+2 [id="ebarilan-devstack", vitrage_sample_timestamp="2018-12-31T13:44:03Z", vitrage_datasource_name="nova.host", vitrage_operational_state=OK, state=available, update_timestamp="2018-12-31T13:44:03Z", is_real_vitrage_id=True, vitrage_id="10da4fa2-397f-4b2e-a43b-937e11ab7daf", vitrage_aggregated_state=AVAILABLE, vitrage_type="nova.host", vitrage_is_deleted=False, vitrage_category=RESOURCE, vitrage_cached_id="9ae4db6fb920e19cb5c57a428b29eb59", vitrage_is_placeholder=False, label="ebarilan-devstack\\nnova.host"];
+3 [id="b36b4d7a-b309-4b02-9662-5abd79741750", vitrage_sample_timestamp="2018-12-31T13:44:04Z", vitrage_datasource_name="cinder.volume", project_id="210140f1f5a94af99e0adf79a883b75a", vitrage_operational_state=OK, vitrage_aggregated_state=AVAILABLE, vitrage_is_placeholder=False, state=available, attachments="[]", vitrage_id="f0ca9fac-3ebd-4748-97ba-e93a7e7108aa", size=1, vitrage_type="cinder.volume", vitrage_is_deleted=False, vitrage_category=RESOURCE, vitrage_cached_id=f998c5f7bf1851e17e3eea902800a7df, update_timestamp="2018-12-31T08:43:32Z", is_real_vitrage_id=True, volume_type="lvmdriver-1", label="cinder.volume"];
+4 [id="cebf5d5b-d7b1-4cfb-86fa-f660306b4c1a", vitrage_sample_timestamp="2018-12-31T13:44:04Z", vitrage_datasource_name="neutron.network", project_id="210140f1f5a94af99e0adf79a883b75a", vitrage_operational_state=OK, vitrage_category=RESOURCE, vitrage_is_placeholder=False, state=ACTIVE, update_timestamp="2018-12-30T08:30:33Z", is_real_vitrage_id=True, vitrage_id="eea46e33-81dc-4430-a771-852bac37b43d", vitrage_aggregated_state=ACTIVE, vitrage_type="neutron.network", vitrage_is_deleted=False, vitrage_cached_id=a0eeca0ab2c865915e23319a2e6d0fd7, label="public\\nneutron.network"];
 0 -> 2 [vitrage_is_deleted=False, label=contains];
 1 -> 0 [vitrage_is_deleted=False, label=contains];
 }
